@@ -47,8 +47,8 @@ use Unicode::LineBreak qw(:all);
 
 ### Globals
 
-### The package version, both in 1.23 style *and* usable by MakeMaker:
-our $VERSION = '1.000';
+### The package Version
+our $VERSION = '2011.002_26';
 
 ### Public Configuration Attributes
 our $Config = {
@@ -162,7 +162,7 @@ Get or update configuration.  Following KEY => VALUE pairs may be specified.
 =item Charset => CHARSET
 
 Character set that is used to encode string.
-It may be string or instance of L<MIME::Charset> object.
+It may be string or L<MIME::Charset> object.
 Default is C<"UTF-8">.
 
 =item Language => LANGUAGE
@@ -180,7 +180,7 @@ Default is C<"\n">.
 =item OutputCharset => CHARSET
 
 Character set that is used to encode result of fold()/unfold().
-It may be string or instance of L<MIME::Charset> object.
+It may be string or L<MIME::Charset> object.
 If a special value C<"_UNICODE_"> is specified, result will be Unicode string.
 Default is the value of Charset option.
 
@@ -196,18 +196,18 @@ Default is 8.
 
 =item ColumnsMax
 
+=item EAWidth
+
 =item HangulAsAL
 
+=item LBClass
+
 =item LegacyCM
 
-=item TailorEA
-
-=item TailorLB
+=item Prep
 
 =item UrgentBreaking
 
-=item UserBreaking
-
 See L<Unicode::LineBreak/Options>.
 
 =back
@@ -271,8 +271,7 @@ sub config {
     ## Note: Example in Unicode::LineBreak POD treats $spcstr as Perl string.
     ## Following code is more efficient.
     $self->SUPER::config(SizingMethod => sub {
-	my ($self, $cols, $pre, $spc, $str, $max) = @_;
-	return undef if $max;
+	my ($self, $cols, $pre, $spc, $str) = @_;
 
 	my $tabsize = $self->{TabSize};
 	my $spcstr = $spc.$str;
@@ -289,8 +288,7 @@ sub config {
     });
 
     ## Classify horizontal tab as line breaking class SP.
-    my @tailor_lb = @{$self->SUPER::config('TailorLB')};
-    $self->SUPER::config(TailorLB => [@tailor_lb, ord("\t") => LB_SP]);
+    $self->SUPER::config(LBClass => [ord("\t") => LB_SP]);
     ## Tab size
     if (defined $self->{TabSize}) {
 	croak "Invalid TabSize option" unless $self->{TabSize} =~ /^\d+$/;
@@ -596,7 +594,7 @@ L<Unicode::LineBreak>, L<Text::Wrap>.
 
 =head1 AUTHOR
 
-Copyright (C) 2009 Hatuka*nezumi - IKEDA Soji <hatuka(at)nezumi.nu>.
+Copyright (C) 2009-2011 Hatuka*nezumi - IKEDA Soji <hatuka(at)nezumi.nu>.
 
 This program is free software; you can redistribute it and/or modify it 
 under the same terms as Perl itself.
